==> odata-client-microsoft-dynamics-0.1.38-sources.jar: microsoft/dynamics/crm/entity/request/LookupmappingRequest.java <==
package microsoft.dynamics.crm.entity.request;

import com.fasterxml.jackson.annotation.JsonIgnoreType;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.EntityRequest;

import java.lang.Object;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Lookupmapping;
import microsoft.dynamics.crm.schema.SchemaInfo;

@JsonIgnoreType
public class LookupmappingRequest extends EntityRequest<Lookupmapping> {

    public LookupmappingRequest(ContextPath contextPath, Optional<Object> value) {
        super(Lookupmapping.class, contextPath, SchemaInfo.INSTANCE, value);
    }

    public SystemuserRequest modifiedby() {
        return new SystemuserRequest(contextPath.addSegment("modifiedby"), Optional.empty());
    }

    public TransformationparametermappingRequest transformationparametermappingid() {
        return new TransformationparametermappingRequest(contextPath.addSegment("transformationparametermappingid"), Optional.empty());
    }

    public SystemuserRequest createdby() {
        return new SystemuserRequest(contextPath.addSegment("createdby"), Optional.empty());
    }

    public SystemuserRequest modifiedonbehalfby() {
        return new SystemuserRequest(contextPath.addSegment("modifiedonbehalfby"), Optional.empty());
    }

    public SystemuserRequest createdonbehalfby() {
        return new SystemuserRequest(contextPath.addSegment("createdonbehalfby"), Optional.empty());
    }

    public ColumnmappingRequest columnmappingid() {
        return new ColumnmappingRequest(contextPath.addSegment("columnmappingid"), Optional.empty());
    }

}

==> odata-client-microsoft-dynamics-0.1.39-sources.jar: microsoft/dynamics/crm/entity/request/LookupmappingRequest.java <==
package microsoft.dynamics.crm.entity.request;

import com.fasterxml.jackson.annotation.JsonIgnoreType;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.EntityRequest;

import java.lang.Object;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Lookupmapping;

@JsonIgnoreType
public class LookupmappingRequest extends EntityRequest<Lookupmapping> {

    public LookupmappingRequest(ContextPath contextPath, Optional<Object> value) {
        super(Lookupmapping.class, contextPath, value);
    }

    public SystemuserRequest modifiedby() {
        return new SystemuserRequest(contextPath.addSegment("modifiedby"), Optional.empty());
    }

    public TransformationparametermappingRequest transformationparametermappingid() {
        return new TransformationparametermappingRequest(contextPath.addSegment("transformationparametermappingid"), Optional.empty());
    }

    public SystemuserRequest createdby() {
        return new SystemuserRequest(contextPath.addSegment("createdby"), Optional.empty());
    }

    public SystemuserRequest modifiedonbehalfby() {
        return new SystemuserRequest(contextPath.addSegment("modifiedonbehalfby"), Optional.empty());
    }

    public SystemuserRequest createdonbehalfby() {
        return new SystemuserRequest(contextPath.addSegment("createdonbehalfby"), Optional.empty());
    }

    public ColumnmappingRequest columnmappingid() {
        return new ColumnmappingRequest(contextPath.addSegment("columnmappingid"), Optional.empty());
    }

}
